###########
Aldryn Jobs
###########

|PyPI_Version| |Build_Status| |Coverage_Status| |codeclimate| |requires_io|

|Browser_Matrix|

Aldryn Jobs is an Aldryn-compatible django CMS application for publishing
job openings and receiving applications.

Please see the `Aldryn Jobs documentation <http://aldryn-jobs.readthedocs.org>`_,
which includes information on installation and getting started.

It also contains `documentation for content editors and end-users
<http://aldryn-jobs.readthedocs.org/en/latest/user/index.html>`_.

************
Contributing
************

Aldryn Jobs is a an open-source project. We'll be delighted to receive your
feedback in the form of issues and pull requests. Before submitting your pull
request, please review our
`guidelines for Aldryn Addons <http://docs.aldryn.com/en/latest/reference/addons/index.html>`_.


************
Requirements
************

* django CMS 3.0.12, 3.1.x or 3.2.x
* Django 1.6.9, 1.7.x, or 1.8.x


.. |PyPI_Version| image:: http://img.shields.io/pypi/v/aldryn-jobs.svg
   :target: https://pypi.python.org/pypi/aldryn-jobs
.. |Build_Status| image:: http://img.shields.io/travis/aldryn/aldryn-jobs/master.svg
   :target: https://travis-ci.org/aldryn/aldryn-jobs
.. |Coverage_Status| image:: http://img.shields.io/coveralls/aldryn/aldryn-jobs/master.svg
   :target: https://coveralls.io/r/aldryn/aldryn-jobs?branch=master
.. |codeclimate| image:: https://codeclimate.com/github/aldryn/aldryn-jobs/badges/gpa.svg
   :target: https://codeclimate.com/github/aldryn/aldryn-jobs
   :alt: Code Climate
.. |requires_io| image:: https://requires.io/github/aldryn/aldryn-jobs/requirements.svg?branch=master
   :target: https://requires.io/github/aldryn/aldryn-jobs/requirements/?branch=master
   :alt: Requirements Status
.. |Browser_Matrix| image:: https://saucelabs.com/browser-matrix/aldryn-jobs.svg
   :target: https://saucelabs.com/u/aldryn-jobs
